'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _colors = require('./colors');

var _colors2 = _interopRequireDefault(_colors);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function hexToRGBA(hex) {
  var alpha = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;

  var r = parseInt(hex.slice(1, 3), 16);
  var g = parseInt(hex.slice(3, 5), 16);
  var b = parseInt(hex.slice(5, 7), 16);

  return 'rgba(' + r + ', ' + g + ', ' + b + ', ' + alpha + ')';
}

exports.default = {
  button: {
    display: 'inline-block',
    width: '100%',
    height: '50px',
    position: 'relative',

    boxSizing: 'border-box',

    border: 'none',
    borderRadius: '4px',

    fontSize: '16px',
    textAlign: 'center',
    letterSpacing: '1.5px',
    textTransform: 'uppercase',
    textDecoration: 'none',

    color: '#fff',
    backgroundSize: '200% 200%',

    zIndex: 0,
    cursor: 'pointer',
    overflow: 'hidden',
    transform: 'translateZ(0)',
    transition: 'box-shadow 0.3s ease, background-position 0.3s ease',
    backgroundColor: function backgroundColor(_ref) {
      var color = _ref.color;
      return _colors2.default[color][0];
    },
    backgroundImage: function backgroundImage(_ref2) {
      var color = _ref2.color;
      return 'radial-gradient(\n      ellipse at center,\n      ' + _colors2.default[color][1] + ' 0%,\n      ' + hexToRGBA(_colors2.default[color][0], 0) + ' 60%,\n      ' + _colors2.default[color][0] + ' 100%\n    )';
    },

    '&:focus': {
      outline: 'none',
      boxShadow: 'rgba(0, 0, 0, 0.4) 0 4px 4px 0',
      backgroundPosition: '50% 50%'
    },

    '&:hover': {
      boxShadow: 'rgba(0, 0, 0, 0.3) 0 8px 8px 0',
      backgroundPosition: '100% 100%'
    }
  },

  effect: {
    display: 'block',
    position: 'absolute',

    borderRadius: '100%',

    zIndex: '-1',
    animation: function animation(props) {
      return 'ripple ' + props.animationDuration + 'ms linear both';
    },
    backgroundImage: function backgroundImage(_ref3) {
      var color = _ref3.color;
      return 'radial-gradient(\n      ellipse at center,\n      ' + hexToRGBA(_colors2.default[color][0], 0) + ' 0%,\n      ' + _colors2.default[color][1] + ' 7%,\n      ' + _colors2.default[color][1] + ' 30%,\n      ' + hexToRGBA(_colors2.default[color][0], 0) + ' 60%,\n      ' + hexToRGBA(_colors2.default[color][0], 0.3) + ' 100%\n    )';
    }
  },

  '@keyframes ripple': {
    from: {
      opacity: 1,
      transform: 'translate3d(-50%, -50%, 0) scale(0)'
    },

    to: {
      opacity: 0,
      transform: 'translate3d(-50%, -50%, 0) scale(3)'
    }
  }
};